@@ -19,7 +19,7 @@ def init_pycli(title, logger_name, log_file_name):
     print(f'[blue]{title}[/blue]')
     FORMAT = "%(message)s"
     #logging.basicConfig(format=FORMAT, datefmt="[%X]", level="NOTSET", handlers=[RichHandler(rich_tracebacks=True, markup=True)], filename=logger_name)
-    logging.basicConfig(format=FORMAT, datefmt="[%X]", level="NOTSET", filename=logger_name)
+    logging.basicConfig(format=FORMAT, datefmt="[%X]", level="NOTSET")
     traceback.install()
 
     log = logging.getLogger(logger_name)
@@ -43,15 +43,14 @@ class pyclibase(object):
         """
         # Run command
 
+        log.info('Executing cmd: {0}'.format(cmd))
         ps = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, executable='/bin/bash')
         while True:
             retcode = ps.poll()
             # THIS TRY, EXCEPT IS ADDED AS PRINT LINE MIGHT FAIL RANDOMLY FOR UNICODEENCODEERROR
             try:
                 line = ps.stdout.readline().decode('ISO-8859-1')
-                log.info(line)
-                #sys.stdout.write(line)
-                #sys.stdout.flush()
+                log.info(line.strip())
             except UnicodeEncodeError as err:
                 log.error("\nException occured while trying to print line.\n{0}".format(err))
             if retcode is not None and line == '':
@@ -62,6 +61,7 @@ class pyclibase(object):
     def execute_cmd_get_output(self, cmd:str):
         output = None
         try:
+            log.info('Executing cmd: {0}'.format(cmd))
             output = subprocess.check_output(cmd, timeout=60*60, shell=True, stderr=subprocess.DEVNULL)
         except Exception as generic_exception:
             log.error('Caught Exception: {}'.format(generic_exception))
